@@ -1,7 +1,7 @@
 package Socialtext::WikiObject::YAML;
 use strict;
 use warnings;
-use base 'Socialtext::WikiObject';
+use base 'Socialtext::WikiObject::PreBlock';
 use YAML;
 
 =head1 NAME
@@ -24,10 +24,8 @@ sub parse_wikitext {
     my $self = shift;
     my $wikitext = shift;
 
-    # Load the YAML
-    $wikitext =~ s/^\.pre\n(.+)\.pre.+$/$1/s;
-    chomp $wikitext;
-    $wikitext .= "\n";
+    $self->SUPER::parse_wikitext($wikitext);
+    $wikitext = $self->pre_block;
 
     my $data = {};
     eval { $data = Load($wikitext) };
